@@ -1,5 +1,6 @@
 /*
  * Copyright (C) 2009 Pierre-Luc Beaudoin <pierre-luc@pierlux.com>
+ * Copyright (C) 2011 Jiri Techet <techet@gmail.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -50,6 +51,14 @@ typedef struct _ChamplainMapSourceDescPrivate ChamplainMapSourceDescPrivate;
 typedef struct _ChamplainMapSourceDesc ChamplainMapSourceDesc;
 typedef struct _ChamplainMapSourceDescClass ChamplainMapSourceDescClass;
 
+/**
+ * ChamplainMapSourceDesc:
+ *
+ * The #ChamplainMapSourceDesc structure contains only private data
+ * and should be accessed using the provided API
+ *
+ * Since: 0.10
+ */
 struct _ChamplainMapSourceDesc
 {
   GObject parent_instance;
@@ -73,25 +82,31 @@ struct _ChamplainMapSourceDescClass
  *
  * Since: 0.10
  */
-typedef ChamplainMapSource * (*ChamplainMapSourceConstructor)
-  (ChamplainMapSourceDesc *desc);
+typedef ChamplainMapSource* (*ChamplainMapSourceConstructor) (ChamplainMapSourceDesc *desc);
 
+/**
+ * CHAMPLAIN_MAP_SOURCE_CONSTRUCTOR:
+ *
+ * Conversion macro to #ChamplainMapSourceConstructor.
+ *
+ * Since: 0.10
+ */
 #define CHAMPLAIN_MAP_SOURCE_CONSTRUCTOR (f) ((ChamplainMapSourceConstructor) (f))
 
 GType champlain_map_source_desc_get_type (void);
 
 ChamplainMapSourceDesc *champlain_map_source_desc_new_full (
-  gchar *id,
-  gchar *name,
-  gchar *license,
-  gchar *license_uri,
-  guint min_zoom,
-  guint max_zoom,
-  guint tile_size,
-  ChamplainMapProjection projection,
-  gchar *uri_format,
-  ChamplainMapSourceConstructor constructor,
-  gpointer data);
+    gchar *id,
+    gchar *name,
+    gchar *license,
+    gchar *license_uri,
+    guint min_zoom,
+    guint max_zoom,
+    guint tile_size,
+    ChamplainMapProjection projection,
+    gchar *uri_format,
+    ChamplainMapSourceConstructor constructor,
+    gpointer data);
 
 const gchar *champlain_map_source_desc_get_id (ChamplainMapSourceDesc *desc);
 const gchar *champlain_map_source_desc_get_name (ChamplainMapSourceDesc *desc);
