@@ -25,10 +25,10 @@
 #define CHAMPLAIN_VIEW_H
 
 #include <champlain/champlain-defines.h>
-#include <champlain/champlain-base-marker.h>
 #include <champlain/champlain-layer.h>
-#include <champlain/champlain-polygon.h>
 #include <champlain/champlain-map-source.h>
+#include <champlain/champlain-license.h>
+#include <champlain/champlain-bounding-box.h>
 
 #include <glib.h>
 #include <glib-object.h>
@@ -55,43 +55,25 @@ G_BEGIN_DECLS
 
 typedef struct _ChamplainViewPrivate ChamplainViewPrivate;
 
-/**
- * ChamplainScrollMode:
- * @CHAMPLAIN_SCROLL_MODE_PUSH: Non-kinetic scrolling
- * @CHAMPLAIN_SCROLL_MODE_KINETIC: Kinetic scrolling
- *
- * Type of scrolling.
- */
-typedef enum
-{
-  CHAMPLAIN_SCROLL_MODE_PUSH,
-  CHAMPLAIN_SCROLL_MODE_KINETIC
-} ChamplainScrollMode;
-
 
 /**
- * ChamplainUnit:
- * @CHAMPLAIN_UNIT_KM: kilometers
- * @CHAMPLAIN_UNIT_MILES: miles
+ * ChamplainView:
  *
- * Units used by the scale.
+ * The #ChamplainView structure contains only private data
+ * and should be accessed using the provided API
+ *
+ * Since: 0.1
  */
-typedef enum
-{
-  CHAMPLAIN_UNIT_KM,
-  CHAMPLAIN_UNIT_MILES,
-} ChamplainUnit;
-
 struct _ChamplainView
 {
-  ClutterGroup group;
+  ClutterActor parent;
 
   ChamplainViewPrivate *priv;
 };
 
 struct _ChamplainViewClass
 {
-  ClutterGroupClass parent_class;
+  ClutterActorClass parent_class;
 };
 
 GType champlain_view_get_type (void);
@@ -105,87 +87,75 @@ void champlain_view_go_to (ChamplainView *view,
     gdouble latitude,
     gdouble longitude);
 void champlain_view_stop_go_to (ChamplainView *view);
+gdouble champlain_view_get_center_latitude (ChamplainView *view);
+gdouble champlain_view_get_center_longitude (ChamplainView *view);
 
 void champlain_view_zoom_in (ChamplainView *view);
 void champlain_view_zoom_out (ChamplainView *view);
 void champlain_view_set_zoom_level (ChamplainView *view,
-    gint zoom_level);
+    guint zoom_level);
 void champlain_view_set_min_zoom_level (ChamplainView *view,
-    gint zoom_level);
+    guint zoom_level);
 void champlain_view_set_max_zoom_level (ChamplainView *view,
-    gint zoom_level);
+    guint zoom_level);
 
 void champlain_view_ensure_visible (ChamplainView *view,
-    gdouble lat1,
-    gdouble lon1,
-    gdouble lat2,
-    gdouble lon2,
+    ChamplainBoundingBox *bbox,
     gboolean animate);
-void champlain_view_ensure_markers_visible (ChamplainView *view,
-    ChamplainBaseMarker *markers[],
+void champlain_view_ensure_layers_visible (ChamplainView *view,
     gboolean animate);
 
 void champlain_view_set_map_source (ChamplainView *view,
     ChamplainMapSource *map_source);
-void champlain_view_set_size (ChamplainView *view,
-    guint width,
-    guint height);
-void champlain_view_set_decel_rate (ChamplainView *view,
+void champlain_view_set_deceleration (ChamplainView *view,
     gdouble rate);
-void champlain_view_set_scroll_mode (ChamplainView *view,
-    ChamplainScrollMode mode);
+void champlain_view_set_kinetic_mode (ChamplainView *view,
+    gboolean kinetic);
 void champlain_view_set_keep_center_on_resize (ChamplainView *view,
     gboolean value);
-void champlain_view_set_show_license (ChamplainView *view,
-    gboolean value);
-void champlain_view_set_license_text (ChamplainView *view,
-    const gchar *text);
-void champlain_view_set_show_scale (ChamplainView *view,
-    gboolean value);
-void champlain_view_set_scale_unit (ChamplainView *view,
-    ChamplainUnit unit);
-void champlain_view_set_max_scale_width (ChamplainView *view,
-    guint value);
 void champlain_view_set_zoom_on_double_click (ChamplainView *view,
     gboolean value);
+void champlain_view_set_animate_zoom (ChamplainView *view,
+    gboolean value);
 
 void champlain_view_add_layer (ChamplainView *view,
     ChamplainLayer *layer);
 void champlain_view_remove_layer (ChamplainView *view,
     ChamplainLayer *layer);
 
-gboolean champlain_view_get_coords_from_event (ChamplainView *view,
-    ClutterEvent *event,
-    gdouble *lat,
-    gdouble *lon);
-
-gboolean champlain_view_get_coords_at (ChamplainView *view,
-    guint x,
-    guint y,
-    gdouble *lat,
-    gdouble *lon);
-
-gint champlain_view_get_zoom_level (ChamplainView *view);
-gint champlain_view_get_min_zoom_level (ChamplainView *view);
-gint champlain_view_get_max_zoom_level (ChamplainView *view);
+guint champlain_view_get_zoom_level (ChamplainView *view);
+guint champlain_view_get_min_zoom_level (ChamplainView *view);
+guint champlain_view_get_max_zoom_level (ChamplainView *view);
 ChamplainMapSource *champlain_view_get_map_source (ChamplainView *view);
-gdouble champlain_view_get_decel_rate (ChamplainView *view);
-ChamplainScrollMode champlain_view_get_scroll_mode (ChamplainView *view);
+gdouble champlain_view_get_deceleration (ChamplainView *view);
+gboolean champlain_view_get_kinetic_mode (ChamplainView *view);
 gboolean champlain_view_get_keep_center_on_resize (ChamplainView *view);
-gboolean champlain_view_get_show_license (ChamplainView *view);
-const gchar *champlain_view_get_license_text (ChamplainView *view);
-gboolean champlain_view_get_show_scale (ChamplainView *view);
-guint champlain_view_get_max_scale_width (ChamplainView *view);
-ChamplainUnit champlain_view_get_scale_unit (ChamplainView *view);
 gboolean champlain_view_get_zoom_on_double_click (ChamplainView *view);
-
-void champlain_view_add_polygon (ChamplainView *view,
-    ChamplainPolygon *polygon);
-void champlain_view_remove_polygon (ChamplainView *view,
-    ChamplainPolygon *polygon);
+gboolean champlain_view_get_animate_zoom (ChamplainView *view);
+ChamplainState champlain_view_get_state (ChamplainView *view);
 
 void champlain_view_reload_tiles (ChamplainView *view);
 
+gdouble champlain_view_x_to_longitude (ChamplainView *view,
+    gdouble x);
+gdouble champlain_view_y_to_latitude (ChamplainView *view,
+    gdouble y);
+gdouble champlain_view_longitude_to_x (ChamplainView *view,
+    gdouble longitude);
+gdouble champlain_view_latitude_to_y (ChamplainView *view,
+    gdouble latitude);
+
+void champlain_view_get_viewport_origin (ChamplainView *view,
+    gint *x,
+    gint *y);
+
+void champlain_view_bin_layout_add (ChamplainView *view,
+    ClutterActor *child,
+    ClutterBinAlignment x_align,
+    ClutterBinAlignment y_align);
+
+ChamplainLicense *champlain_view_get_license_actor (ChamplainView *view);
+
 G_END_DECLS
 
 #endif
